from pydantic.types import Enum
from enum import Enum


class OrderProcesses(str, Enum):
    without_payment = "The-devs.Shop.CreateOrder"
    tg_payment = "The-devs.Shop.MakeOrderWithTelegramPayments"
    ton_payment = "The-devs.Shop.MakeOrderWithTONPayments"
    life_pay = "The-devs.Shop.CreateLinkPaymentsOrder"


class PaymentTypes(str, Enum):
    manual_payment_request = "ManualPaymentRequest"
    external_card_payment_provider = "ExternalCardPaymentProvider"
    crypto_ton = "CryptoTON"
    xtr = "XTR"
    life_pay = "LifePay"
    yookassa = "yookassa"
    tkassa = "tkassa"



class ShopStatuses(str, Enum):
    deploying = 'deploying'
    active = 'active'
    importing = 'importing'
    blocked = 'blocked'
    unavailable = 'unavailable'
    deleted = 'deleted'


class TaskStatuses(str, Enum):
    pending = 'pending'
    expired = 'expired'
    completed = 'completed'


class ServiceNames(str, Enum):
    bot = 'bot'


class UserRoles(str, Enum):
    user = 'user'
    admin = 'admin'
    shop_admin = 'shop_admin'
    shop_manager = 'shop_manager'


PAYMENTS_PROCESSES_MAPPING = {
    PaymentTypes.manual_payment_request.value: OrderProcesses.without_payment.value,
    PaymentTypes.external_card_payment_provider.value: OrderProcesses.tg_payment.value,
    PaymentTypes.xtr.value: OrderProcesses.tg_payment.value,
    PaymentTypes.crypto_ton.value: OrderProcesses.ton_payment.value,
    PaymentTypes.life_pay.value: OrderProcesses.life_pay.value,
    PaymentTypes.yookassa.value: OrderProcesses.life_pay.value,
    PaymentTypes.tkassa.value: OrderProcesses.life_pay.value,
}




from typing import Optional, Dict, Any
from pydantic import Field, HttpUrl
from fastapi import HTTPException
from pydantic import BaseModel, field_validator



from shop_system_models.shop_api import MetaBaseModel


class ServiceLink(MetaBaseModel):
    """Model representing a link to another service."""
    service_name: str
    url: HttpUrl
    resource_id: str
    link_metadata: Optional[Dict[str, Any]] = Field(default_factory=lambda: {})


class ServiceLinkResponse(MetaBaseModel):
    """Response model for service link operations."""
    link_id: str
    service_name: str
    resource_id: str
    success: bool = True
    error: Optional[str] = None


class LinkBlocksModel(BaseModel):
    contacts: str | None = "https://teletype.in/@tg-shops/09hOkoJjizN"  # Teletype link
    info: str | None = "https://teletype.in/@tg-shops/2vZa_0ykcCF"  # Teletype link

    @field_validator("contacts", "info", mode="before")
    def link_validation(cls, value):
        if value and (not value.startswith("http://") and not value.startswith("https://")):
            raise HTTPException(status_code=400, detail=f'Invalid link: "{value}"')
        return value



from typing import Dict, Optional
from pydantic import BaseModel

class Thumbnail(BaseModel):
    signedUrl: Optional[str] = None
    path: Optional[str] = None

class Thumbnails(BaseModel):
    tiny: Optional[Thumbnail]
    small: Optional[Thumbnail]
    card_cover: Optional[Thumbnail]

class ImageMetadata(BaseModel):
    id: Optional[str] = None
    url: Optional[str] = None
    title: Optional[str] = None
    mimetype: Optional[str] = None
    thumbnails: Optional[Thumbnails]
    path: Optional[str] = None
    signedUrl: Optional[str] = None



from _typeshed import Incomplete
from enum import Enum

class OrderProcesses(str, Enum):
    without_payment: str
    tg_payment: str
    ton_payment: str
    life_pay: str

class PaymentTypes(str, Enum):
    manual_payment_request: str
    external_card_payment_provider: str
    crypto_ton: str
    xtr: str
    life_pay: str
    yookassa: str
    tkassa: str

class ShopStatuses(str, Enum):
    deploying: str
    active: str
    importing: str
    blocked: str
    unavailable: str
    deleted: str

class TaskStatuses(str, Enum):
    pending: str
    expired: str
    completed: str

class ServiceNames(str, Enum):
    bot: str

class UserRoles(str, Enum):
    user: str
    admin: str
    shop_admin: str
    shop_manager: str

PAYMENTS_PROCESSES_MAPPING: Incomplete



from shops_payment_processing.models.invoice import InvoiceWithPaymentLinkMessageModel # type: ignore

from shop_system_models.shop_api.commands.request import NotificationPayloadModel
from shop_system_models.shop_api.shop.request.orders import InvoiceTGMessageModel, InvoiceTONMessageModel
from shop_system_models.shop_api.shop.request.orders import InvoiceWithPaymentLinkMessageModel as InvoiceWithPaymentLinkMessageModelLocal
from pydantic import BaseModel


class SetAdminMessageIdProcess(BaseModel):
    admin_message_id: int | None = None


class SetProcessStatus(BaseModel):
    message: str | None = None
    success: bool | None = None


class ProcessModel(SetAdminMessageIdProcess, SetProcessStatus):
    name: str
    process_key: int
    order_id: str


class ProcessVariables(BaseModel):
    order_id: str
    shop_url: str
    shop_id: str
    shop_api_url: str
    shop_bot_url: str
    user_order_info: NotificationPayloadModel
    admin_order_info: NotificationPayloadModel
    payment_info: (InvoiceTGMessageModel
                   | InvoiceTONMessageModel
                   | InvoiceWithPaymentLinkMessageModel
                   | InvoiceWithPaymentLinkMessageModelLocal
                   | None) = None
    send_to_admin_dm: bool = False
    shop_language: str



import enum

from pydantic import BaseModel


class PremiumPlanTypes(str, enum.Enum):
    month = '1month'
    three_months = '3months'
    six_months = '6months'
    year = '12months'


class RequestPremiumModel(BaseModel):
    shop_id: str
    premium_type: PremiumPlanTypes



from typing import Optional, List, Dict, Any
from pydantic import Field, validator

from shop_system_models.shop_api import MetaBaseModel


class ShopCreateRequest(MetaBaseModel):
    """Request model for shop creation."""
    name: str
    description: Optional[str] = None
    owner_id: str
    categories: List[str] = Field(default_factory=list)
    
    @validator('name')
    def validate_name(cls, v):
        if not v.strip():
            raise ValueError('Shop name cannot be empty')
        return v


class ShopUpdateRequest(MetaBaseModel):
    """Request model for shop update."""
    shop_id: str
    name: Optional[str] = None
    description: Optional[str] = None
    categories: Optional[List[str]] = None
    settings: Optional[Dict[str, Any]] = None 


from typing import List, Optional
from pydantic import Field
from pydantic import BaseModel

from shop_system_models.shop_api import MetaBaseModel
from shop_system_models.shop_api.shop.request.orders import OrderModel, DeliveryTypeModel
from shop_system_models.shop_api.shop.response.products import PaginationResponseModel


class OrderResponseModel(OrderModel):
    """Response model for a single order."""
    id: str


class OrderListResponseModel(BaseModel):
    """Response model for a list of orders."""
    orders: List[OrderResponseModel]
    page_info: PaginationResponseModel


class DeliveryTypeResponseModel(DeliveryTypeModel):
    """Response model for a delivery type."""
    id: str 